%%%%%     Taal Levi's Matlab Code      %%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%Parameters associated with hunting%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

er=.02;%coefficient that converts game density to encounter rate
d=.1;%kill rate associated with weapon choice
K=25;%Carrying capacity
r=.07;%Population growth rate
hphy=40;
theta=1;
sigma=6;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%Landscape and Settlements%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sizex=200;%x-dimension of landscape
sizey=100;%y-dimension of landscape
N=zeros(sizey,sizex);%%the population density at each gridcell 
num_settlements=25;%%Number of settlements
settlements=zeros(num_settlements,2);%%spatial location of settlements
settlements(:,1)=round(rand(num_settlements,1)*sizex/2);%%randomly generated coordinates, but the user can specify the coordinates
settlements(:,2)=round(rand(num_settlements,1)*sizey/2);
population=round(rand(num_settlements,1)*100);%%randomly generated hunter population, but this can be specified instead
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for i=1:sizey
    for j=1:sizex  %iterate through all space and use the formula to find the steady state game density
        %for num=1:num_settlements
        N(i,j)=(max(0,K^theta*(1-er*d*hphy/r*sum(population(1:num_settlements).*exp(-1/(2*sigma^2)*((settlements(1:num_settlements,1)-j).^2+(settlements(1:num_settlements,2)-i).^2))./(2*pi()*sqrt((settlements(1:num_settlements,1)-j).^2+(settlements(1:num_settlements,2)-i).^2)+1)))))^(1/theta);
    end
end
figure
subplot(2,1,1);pcolor(N);shading interp;colorbar();title('Landscape Scale Game Depletion  ','fontsize',14,'fontweight','b') %open a new figure and create a colormap


%%%%Summarize depletion with a cumulative distribution function, and place a
%%%%red dot at the point of local extirpation
cdf=zeros(K,1);
for i=1:K
    cdf(i)=mean(N(:)<=i);
end
subplot(2,1,2);plot(cdf,'k');title('Cumulative Distribution Function  ','fontsize',14,'fontweight','b');axis([0 25 0 1]);grid on;box off;
hold on;
scatter(1,cdf(1),100,'b','filled');
hold on;
text(1,cdf(1)+.1,'fraction extirpated  ','fontsize',12)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Find Global CPUE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
CPUEtop=0;
CPUEbottom=0;
for i=1:sizey
    for j=1:sizex  %iterate through all space and use the formula to find the steady state game density
            CPUEtop=CPUEtop+N(i,j)*sum(exp(-1/(2*sigma^2)*population(:).*((settlements(:,1)-j).^2+(settlements(:,2)-i).^2)));
            CPUEbottom=CPUEbottom+sum(exp(-1/(2*sigma^2)*population(:).*((settlements(:,1)-j).^2+(settlements(:,2)-i).^2)));
    end
end
CPUE=CPUEtop/CPUEbottom*er*d*1000;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Find Local CPUE of each settlement
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
local=zeros(num_settlements,1);

for num=1:num_settlements
    CPUEtop=0;
    CPUEbottom=0;
    for i=1:sizey
         for j=1:sizex  %iterate through all space and use the formula to find the steady state game density
            CPUEtop=CPUEtop+N(i,j)*exp(-1/(2*sigma^2)*population(num).*((settlements(num,1)-j).^2+(settlements(num,2)-i).^2));
            CPUEbottom=CPUEbottom+exp(-1/(2*sigma^2)*population(num).*((settlements(num,1)-j).^2+(settlements(num,2)-i).^2));
         end
    end  
    local(num)=CPUEtop/CPUEbottom*er*d*1000;
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
